/*
-----------------------------------------------------------------------------
-      ATMEL Microcontroller Software Support  -   ROUSSET -
-----------------------------------------------------------------------------
 The software is delivered "AS IS" without warranty or condition of any
 kind, either express, implied or statutory. This includes without
 limitation any warranty or condition with respect to merchantability or
 fitness for any particular purpose, or against the infringements of
 intellectual property rights of others.
-----------------------------------------------------------------------------
- File Name            : aic.inc
- Object               : Advanced Interrupt Controller Definition File.
- Translator           : ARM Software Development Toolkit V2.11a
-
- 1.0 10/03/98 JCZ     : Creation
- 2.0 21/10/98 JCZ     : Clean up.
-----------------------------------------------------------------------------
*/
/*
-----------------------------------------
- Advanced Interrupt Controller Structure
-----------------------------------------
*/
.equ AIC_SMR,0x000        /* Source Mode Register */
.equ AIC_SVR,0x080        /* Source Vector Register */
.equ AIC_IVR,0x100           /* Interrupt Vector Register */
.equ AIC_FVR,0x104           /* Fast Interrupt Vector Register */
.equ AIC_ISR,0x108           /* Interrupt Status Register */
.equ AIC_IPR,0x10c           /* Interrupt Pending Register */
.equ AIC_IMR,0x110           /* Interrupt Mask Register */
.equ AIC_CISR,0x114           /* Core Interrupt Status Register */

.equ AIC_IECR,0x120           /* Interrupt Enable Command Register */
.equ AIC_IDCR,0x124           /* Interrupt Disable Command Register */
.equ AIC_ICCR,0x128           /* Interrupt Clear Command Register */
.equ AIC_ISCR,0x12c           /* Interrupt Set Command Register */
.equ AIC_EOICR,0x130          /* End Of Interrupt Command Register */

/*
---------------------------------
- Interrupt Source Mode Registers
---------------------------------
*/
/*- Source Type Definition */
.equ SRCTYPE,0x60
.equ PRIOR,0x07

/*
---------------------------
- Interrupt Status Register
----------------------------
*/
.equ IRQID,0x1F

/*
---------------------------------
- Interrupt Core Status Register
---------------------------------
*/
.equ NFIQ,0x01
.equ NIRQ,0x02

/*
--------------------------------
- Device Dependancies Definition
--------------------------------
*/
.equ	AIC_BASE,0xFFFFF000

    .IFDEF AT91M40400

.equ FIQ,0
.equ SWIRQ,1
.equ US0IRQ,2
.equ US1IRQ,3
.equ TC0IRQ,4
.equ TC1IRQ,5
.equ TC2IRQ,6

.equ WDIRQ,7
.equ PIOIRQ,8

.equ IRQ0,16
.equ IRQ1,17
.equ IRQ2,18

/*- Really implemented in the 40400 not including the FIQ */
.equ NB_INTERRUPT,18

    .ENDIF   /* AT91M40400 */


